@@ -12,11 +12,13 @@ from .mode import Mode
 from .token import Token
 from .expression import Expression
 
+from .loaders import CachingChoiceLoader
 from .loaders import CachingFileSystemLoader
 from .loaders import ChoiceLoader
 from .loaders import DictLoader
 from .loaders import FileExtensionLoader
 from .loaders import FileSystemLoader
+from .loaders import PackageLoader
 
 from .context import Context
 from .context import DebugUndefined
@@ -42,11 +44,12 @@ from .static_analysis import ContextualTemplateAnalysis
 
 from . import future
 
-__version__ = "1.10.2"
+__version__ = "1.11.0"
 
 __all__ = (
     "AwareBoundTemplate",
     "BoundTemplate",
+    "CachingChoiceLoader",
     "CachingFileSystemLoader",
     "ChoiceLoader",
     "Context",
@@ -66,6 +69,7 @@ __all__ = (
     "is_undefined",
     "Markup",
     "Mode",
+    "PackageLoader",
     "soft_str",
     "StrictDefaultUndefined",
     "StrictUndefined",
